@@ -392,7 +392,7 @@ void
 ExecuteCriticalRemoteCommandList(MultiConnection *connection, List *commandList)
 {
 	const char *command = NULL;
-	foreach_ptr(command, commandList)
+	foreach_declared_ptr(command, commandList)
 	{
 		ExecuteCriticalRemoteCommand(connection, command);
 	}
@@ -435,7 +435,7 @@ ExecuteRemoteCommandInConnectionList(List *nodeConnectionList, const char *comma
 {
 	MultiConnection *connection = NULL;
 
-	foreach_ptr(connection, nodeConnectionList)
+	foreach_declared_ptr(connection, nodeConnectionList)
 	{
 		int querySent = SendRemoteCommand(connection, command);
 
@@ -446,7 +446,7 @@ ExecuteRemoteCommandInConnectionList(List *nodeConnectionList, const char *comma
 	}
 
 	/* Process the result */
-	foreach_ptr(connection, nodeConnectionList)
+	foreach_declared_ptr(connection, nodeConnectionList)
 	{
 		bool raiseInterrupts = true;
 		PGresult *result = GetRemoteCommandResult(connection, raiseInterrupts);
@@ -887,7 +887,7 @@ WaitForAllConnections(List *connectionList, bool raiseInterrupts)
 
 	/* convert connection list to an array such that we can move items around */
 	MultiConnection *connectionItem = NULL;
-	foreach_ptr(connectionItem, connectionList)
+	foreach_declared_ptr(connectionItem, connectionList)
 	{
 		allConnections[connectionIndex] = connectionItem;
 		connectionReady[connectionIndex] = false;
@@ -1130,7 +1130,7 @@ BuildWaitEventSet(MultiConnection **allConnections, int totalConnectionCount,
 
 	/* allocate pending connections + 2 for the signal latch and postmaster death */
 	/* (CreateWaitEventSet makes room for pgwin32_signal_event automatically) */
-	WaitEventSet *waitEventSet = CreateWaitEventSet(CurrentMemoryContext,
+	WaitEventSet *waitEventSet = CreateWaitEventSet(WaitEventSetTracker_compat,
 													pendingConnectionCount + 2);
 
 	for (int connectionIndex = 0; connectionIndex < pendingConnectionCount;
