@@ -202,17 +202,51 @@ DeparseCreateRoleStmt(Node *node)
 }
 
 
+static void
+AppendSysIdStatement(StringInfo buf, ListCell *optionCell)
+{
+	DefElem *option = (DefElem *) lfirst(optionCell);
+	if (strcmp(option->defname, "sysid") == 0)
+	{
+		appendStringInfo(buf, " SYSID %d", intVal(option->arg));
+	}
+}
+
+
 /*
- * AppendCreateRoleStmt generates the string representation of the
- * CreateRoleStmt and appends it to the buffer.
+ * AppendInlinePriviliges generates the string representation for the inline
+ * privileges of the role in create statement and appends it to the buffer.
  */
 static void
-AppendCreateRoleStmt(StringInfo buf, CreateRoleStmt *stmt)
+AppendInlinePriviliges(StringInfo buf, ListCell *optionCell)
 {
-	ListCell *optionCell = NULL;
+	DefElem *option = (DefElem *) lfirst(optionCell);
 
-	appendStringInfo(buf, "CREATE ");
+	if (strcmp(option->defname, "adminmembers") == 0)
+	{
+		appendStringInfo(buf, " ADMIN ");
+		AppendRoleList(buf, (List *) option->arg);
+	}
+	else if (strcmp(option->defname, "rolemembers") == 0)
+	{
+		appendStringInfo(buf, " ROLE ");
+		AppendRoleList(buf, (List *) option->arg);
+	}
+	else if (strcmp(option->defname, "addroleto") == 0)
+	{
+		appendStringInfo(buf, " IN ROLE ");
+		AppendRoleList(buf, (List *) option->arg);
+	}
+}
 
+
+/*
+ * AppendStatementType generates the string representation for the statement
+ * type (role, user or group) in alter/create statement and appends it to the buffer.
+ */
+static void
+AppendStatementType(StringInfo buf, CreateRoleStmt *stmt)
+{
 	switch (stmt->stmt_type)
 	{
 		case ROLESTMT_ROLE:
@@ -233,34 +267,29 @@ AppendCreateRoleStmt(StringInfo buf, CreateRoleStmt *stmt)
 			break;
 		}
 	}
+}
+
+
+/*
+ * AppendCreateRoleStmt generates the string representation of the
+ * CreateRoleStmt and appends it to the buffer.
+ */
+static void
+AppendCreateRoleStmt(StringInfo buf, CreateRoleStmt *stmt)
+{
+	ListCell *optionCell = NULL;
+
+	appendStringInfo(buf, "CREATE ");
+
+	AppendStatementType(buf, stmt);
 
 	appendStringInfo(buf, "%s", quote_identifier(stmt->role));
 
 	foreach(optionCell, stmt->options)
 	{
 		AppendRoleOption(buf, optionCell);
-
-		DefElem *option = (DefElem *) lfirst(optionCell);
-
-		if (strcmp(option->defname, "sysid") == 0)
-		{
-			appendStringInfo(buf, " SYSID %d", intVal(option->arg));
-		}
-		else if (strcmp(option->defname, "adminmembers") == 0)
-		{
-			appendStringInfo(buf, " ADMIN ");
-			AppendRoleList(buf, (List *) option->arg);
-		}
-		else if (strcmp(option->defname, "rolemembers") == 0)
-		{
-			appendStringInfo(buf, " ROLE ");
-			AppendRoleList(buf, (List *) option->arg);
-		}
-		else if (strcmp(option->defname, "addroleto") == 0)
-		{
-			appendStringInfo(buf, " IN ROLE ");
-			AppendRoleList(buf, (List *) option->arg);
-		}
+		AppendInlinePriviliges(buf, optionCell);
+		AppendSysIdStatement(buf, optionCell);
 	}
 }
 
@@ -327,6 +356,22 @@ AppendRoleList(StringInfo buf, List *roleList)
 }
 
 
+char *
+DeparseRenameRoleStmt(Node *node)
+{
+	RenameStmt *stmt = castNode(RenameStmt, node);
+	StringInfoData str = { 0 };
+	initStringInfo(&str);
+
+	Assert(stmt->renameType == OBJECT_ROLE);
+
+	appendStringInfo(&str, "ALTER ROLE %s RENAME TO %s;",
+					 quote_identifier(stmt->subname), quote_identifier(stmt->newname));
+
+	return str.data;
+}
+
+
 /*
  * DeparseGrantRoleStmt builds and returns a string representing of the
  * GrantRoleStmt for application on a remote server.
@@ -366,6 +411,16 @@ AppendRevokeAdminOptionFor(StringInfo buf, GrantRoleStmt *stmt)
 				appendStringInfo(buf, "ADMIN OPTION FOR ");
 				break;
 			}
+			else if (strcmp(opt->defname, "inherit") == 0)
+			{
+				appendStringInfo(buf, "INHERIT OPTION FOR ");
+				break;
+			}
+			else if (strcmp(opt->defname, "set") == 0)
+			{
+				appendStringInfo(buf, "SET OPTION FOR ");
+				break;
+			}
 		}
 	}
 #else
@@ -383,16 +438,29 @@ AppendGrantWithAdminOption(StringInfo buf, GrantRoleStmt *stmt)
 	if (stmt->is_grant)
 	{
 #if PG_VERSION_NUM >= PG_VERSION_16
+		int opt_count = 0;
 		DefElem *opt = NULL;
 		foreach_declared_ptr(opt, stmt->opt)
 		{
-			bool admin_option = false;
 			char *optval = defGetString(opt);
-			if (strcmp(opt->defname, "admin") == 0 &&
-				parse_bool(optval, &admin_option) && admin_option)
+			bool option_value = false;
+			if (parse_bool(optval, &option_value))
 			{
-				appendStringInfo(buf, " WITH ADMIN OPTION");
-				break;
+				opt_count++;
+				char *prefix = opt_count > 1 ? "," : " WITH";
+				if (strcmp(opt->defname, "inherit") == 0)
+				{
+					appendStringInfo(buf, "%s INHERIT %s", prefix, option_value ? "TRUE" :
+									 "FALSE");
+				}
+				else if (strcmp(opt->defname, "admin") == 0 && option_value)
+				{
+					appendStringInfo(buf, "%s ADMIN OPTION", prefix);
+				}
+				else if (strcmp(opt->defname, "set") == 0 && !option_value)
+				{
+					appendStringInfo(buf, "%s SET FALSE", prefix);
+				}
 			}
 		}
 #else
@@ -420,7 +488,6 @@ AppendGrantRoleStmt(StringInfo buf, GrantRoleStmt *stmt)
 	AppendGrantWithAdminOption(buf, stmt);
 	AppendGrantedByInGrantForRoleSpec(buf, stmt->grantor, stmt->is_grant);
 	AppendGrantRestrictAndCascadeForRoleSpec(buf, stmt->behavior, stmt->is_grant);
-	AppendGrantedByInGrantForRoleSpec(buf, stmt->grantor, stmt->is_grant);
 	appendStringInfo(buf, ";");
 }
 
