@@ -4,19 +4,6 @@ CREATE OR REPLACE FUNCTION pg_catalog.citus_prepare_pg_upgrade()
     SET search_path = pg_catalog
     AS $cppu$
 BEGIN
-
-    DELETE FROM pg_depend WHERE
-        objid IN (SELECT oid FROM pg_proc WHERE proname = 'array_cat_agg') AND
-        refobjid IN (select oid from pg_extension where extname = 'citus');
-    --
-    -- We are dropping the aggregates because postgres 14 changed
-    -- array_cat type from anyarray to anycompatiblearray. When
-    -- upgrading to pg14, specifically when running pg_restore on
-    -- array_cat_agg we would get an error. So we drop the aggregate
-    -- and create the right one on citus_finish_pg_upgrade.
-
-    DROP AGGREGATE IF EXISTS array_cat_agg(anyarray);
-    DROP AGGREGATE IF EXISTS array_cat_agg(anycompatiblearray);
     --
     -- Drop existing backup tables
     --
@@ -65,7 +52,7 @@ BEGIN
        address.object_args,
        objects.distribution_argument_index,
        objects.colocationid
-    FROM pg_catalog.pg_dist_object objects,
+    FROM citus.pg_dist_object objects,
          pg_catalog.pg_identify_object_as_address(objects.classid, objects.objid, objects.objsubid) address;
 END;
 $cppu$;
