@@ -1,6 +1,5 @@
--- get_rebalance_progress returns the list of shard placement move operations along with
--- their progressions for ongoing rebalance operations.
---
+DROP FUNCTION pg_catalog.get_rebalance_progress();
+
 CREATE OR REPLACE FUNCTION pg_catalog.get_rebalance_progress()
   RETURNS TABLE(sessionid integer,
                 table_name regclass,
@@ -10,7 +9,11 @@ CREATE OR REPLACE FUNCTION pg_catalog.get_rebalance_progress()
                 sourceport int,
                 targetname text,
                 targetport int,
-                progress bigint)
+                progress bigint,
+                source_shard_size bigint,
+                target_shard_size bigint,
+                operation_type text
+            )
   AS 'MODULE_PATHNAME'
   LANGUAGE C STRICT;
 COMMENT ON FUNCTION pg_catalog.get_rebalance_progress()
