@@ -6,13 +6,10 @@
 DROP FUNCTION pg_catalog.get_rebalance_table_shards_plan;
 CREATE OR REPLACE FUNCTION pg_catalog.get_rebalance_table_shards_plan(
         relation regclass default NULL,
-        threshold float4 default NULL,
+        threshold float4 default 0,
         max_shard_moves int default 1000000,
         excluded_shard_list bigint[] default '{}',
-        drain_only boolean default false,
-        rebalance_strategy name default NULL,
-        improvement_threshold float4 DEFAULT NULL
-    )
+        drain_only boolean default false)
     RETURNS TABLE (table_name regclass,
                    shardid bigint,
                    shard_size bigint,
@@ -22,6 +19,5 @@ CREATE OR REPLACE FUNCTION pg_catalog.get_rebalance_table_shards_plan(
                    targetport int)
     AS 'MODULE_PATHNAME'
     LANGUAGE C VOLATILE;
-COMMENT ON FUNCTION pg_catalog.get_rebalance_table_shards_plan(regclass, float4, int, bigint[], boolean, name, float4)
+COMMENT ON FUNCTION pg_catalog.get_rebalance_table_shards_plan(regclass, float4, int, bigint[], boolean)
     IS 'returns the list of shard placement moves to be done on a rebalance operation';
-
