@@ -194,7 +194,7 @@ BuildGlobalWaitGraph(bool onlyDistributedTx)
 							 "waiting_node_id, waiting_transaction_num, waiting_transaction_stamp, "
 							 "blocking_global_pid,blocking_pid, blocking_node_id, "
 							 "blocking_transaction_num, blocking_transaction_stamp, blocking_transaction_waiting "
-							 "FROM citus_internal_local_blocked_processes()");
+							 "FROM citus_internal.local_blocked_processes()");
 		}
 
 		int querySent = SendRemoteCommand(connection, queryString->data);
@@ -228,7 +228,7 @@ BuildGlobalWaitGraph(bool onlyDistributedTx)
 		else if (!onlyDistributedTx && colCount != 11)
 		{
 			ereport(WARNING, (errmsg("unexpected number of columns from "
-									 "citus_internal_local_blocked_processes")));
+									 "citus_internal.local_blocked_processes")));
 			continue;
 		}
 
