@@ -1,11 +1,3 @@
-SHOW server_version \gset
-SELECT substring(:'server_version', '\d+')::int >= 15 AS server_version_ge_15
-\gset
-\if :server_version_ge_15
-\else
-\q
-\endif
-
 CREATE TABLE alter_am(i int);
 
 INSERT INTO alter_am SELECT generate_series(1,1000000);
