@@ -229,6 +229,8 @@ VACUUM;
 insert into local_vacuum_table select i from generate_series(1,1000000) i;
 delete from local_vacuum_table;
 VACUUM local_vacuum_table;
+VACUUM local_vacuum_table;
+VACUUM local_vacuum_table;
 SELECT CASE WHEN s BETWEEN 20000000 AND 25000000 THEN 22500000 ELSE s END
 FROM pg_total_relation_size('local_vacuum_table') s ;
 
@@ -257,24 +259,53 @@ VACUUM (DISABLE_PAGE_SKIPPING false) local_vacuum_table;
 insert into local_vacuum_table select i from generate_series(1,1000000) i;
 delete from local_vacuum_table;
 VACUUM (INDEX_CLEANUP OFF, PARALLEL 1) local_vacuum_table;
+VACUUM (INDEX_CLEANUP OFF, PARALLEL 1) local_vacuum_table;
+VACUUM (INDEX_CLEANUP OFF, PARALLEL 1) local_vacuum_table;
 SELECT CASE WHEN s BETWEEN 50000000 AND 70000000 THEN 60000000 ELSE s END size
 FROM pg_total_relation_size('local_vacuum_table') s ;
 
 insert into local_vacuum_table select i from generate_series(1,1000000) i;
 delete from local_vacuum_table;
 VACUUM (INDEX_CLEANUP ON, PARALLEL 1) local_vacuum_table;
+VACUUM (INDEX_CLEANUP ON, PARALLEL 1) local_vacuum_table;
+VACUUM (INDEX_CLEANUP ON, PARALLEL 1) local_vacuum_table;
 SELECT CASE WHEN s BETWEEN 20000000 AND 49999999 THEN 35000000 ELSE s END size
 FROM pg_total_relation_size('local_vacuum_table') s ;
 
+-- vacuum (process_toast true) should be vacuuming toast tables (default is true)
+select reltoastrelid from pg_class where relname='local_vacuum_table'
+\gset
+
+SELECT relfrozenxid AS frozenxid FROM pg_class WHERE oid=:reltoastrelid::regclass
+\gset
+insert into local_vacuum_table select i from generate_series(1,10000) i;
+VACUUM (FREEZE, PROCESS_TOAST true) local_vacuum_table;
+SELECT relfrozenxid::text::integer > :frozenxid AS frozen_performed FROM pg_class
+WHERE oid=:reltoastrelid::regclass;
+delete from local_vacuum_table;
+
+-- vacuum (process_toast false) should not be vacuuming toast tables (default is true)
+SELECT relfrozenxid AS frozenxid FROM pg_class WHERE oid=:reltoastrelid::regclass
+\gset
+insert into local_vacuum_table select i from generate_series(1,10000) i;
+VACUUM (FREEZE, PROCESS_TOAST false) local_vacuum_table;
+SELECT relfrozenxid::text::integer = :frozenxid AS frozen_not_performed FROM pg_class
+WHERE oid=:reltoastrelid::regclass;
+delete from local_vacuum_table;
+
 -- vacuum (truncate false) should not attempt to truncate off any empty pages at the end of the table (default is true)
 insert into local_vacuum_table select i from generate_series(1,1000000) i;
 delete from local_vacuum_table;
 vacuum (TRUNCATE false) local_vacuum_table;
+vacuum (TRUNCATE false) local_vacuum_table;
+vacuum (TRUNCATE false) local_vacuum_table;
 SELECT pg_total_relation_size('local_vacuum_table') as size1 \gset
 
 insert into local_vacuum_table select i from generate_series(1,1000000) i;
 delete from local_vacuum_table;
 vacuum (TRUNCATE true) local_vacuum_table;
+vacuum (TRUNCATE true) local_vacuum_table;
+vacuum (TRUNCATE true) local_vacuum_table;
 SELECT pg_total_relation_size('local_vacuum_table') as size2 \gset
 
 SELECT :size1 > :size2 as truncate_less_size;
