@@ -22,25 +22,6 @@ VACUUM (INDEX_CLEANUP "AUTOX") t1;
 VACUUM (FULL, FREEZE, VERBOSE false, ANALYZE, SKIP_LOCKED, INDEX_CLEANUP, PROCESS_TOAST, TRUNCATE) t1;
 VACUUM (FULL, FREEZE false, VERBOSE false, ANALYZE false, SKIP_LOCKED false, INDEX_CLEANUP "Auto", PROCESS_TOAST true, TRUNCATE false) t1;
 
--- vacuum (process_toast true) should be vacuuming toast tables (default is true)
-CREATE TABLE local_vacuum_table(name text);
-select reltoastrelid from pg_class where relname='local_vacuum_table'
-\gset
-
-SELECT relfrozenxid AS frozenxid FROM pg_class WHERE oid=:reltoastrelid::regclass
-\gset
-VACUUM (FREEZE, PROCESS_TOAST true) local_vacuum_table;
-SELECT relfrozenxid::text::integer > :frozenxid AS frozen_performed FROM pg_class
-WHERE oid=:reltoastrelid::regclass;
-
--- vacuum (process_toast false) should not be vacuuming toast tables (default is true)
-SELECT relfrozenxid AS frozenxid FROM pg_class WHERE oid=:reltoastrelid::regclass
-\gset
-VACUUM (FREEZE, PROCESS_TOAST false) local_vacuum_table;
-SELECT relfrozenxid::text::integer = :frozenxid AS frozen_not_performed FROM pg_class
-WHERE oid=:reltoastrelid::regclass;
-
-DROP TABLE local_vacuum_table;
 SET citus.log_remote_commands TO OFF;
 
 create table dist(a int, b int);
@@ -777,4 +758,5 @@ DROP TABLE compression_and_defaults, compression_and_generated_col;
 set client_min_messages to error;
 drop extension postgres_fdw cascade;
 drop schema pg14 cascade;
+DROP ROLE role_1, r1;
 reset client_min_messages;
